==> Zephyrus-2.17.10.11112.tar.gz: Zephyrus-2.17.10.11112/Zephyrus/blog_extension/migrations/0004_auto_20180520_0328.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('cms', '0020_old_tree_cleanup'),
        ('aldryn_categories', '0004_auto_20150623_0859'),
        ('blog_extension', '0003_auto_20180506_1620'),
    ]

    operations = [
        migrations.CreateModel(
            name='FilterPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_filterplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('limit', models.PositiveIntegerField(default=6)),
                ('filterMethod', models.CharField(default=b'or', max_length=3, verbose_name='Filter Method', choices=[(b'or', 'OR'), (b'and', 'AND')])),
                ('renderTemplate', models.CharField(default=b'blog_extension/Default.html', max_length=150, verbose_name='Comment Template', choices=[(b'blog_extension/Default.html', 'Default'), (b'aldryn_newsblog/blog/MayLike.html', b'Blog')])),
                ('catagory', models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True)),
                ('tag', models.ManyToManyField(default=None, to='taggit.Tag', null=True, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='catagory',
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='cmsplugin_ptr',
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='tag',
        ),
        migrations.DeleteModel(
            name='MayLikePlugin',
        ),
    ]

==> Zephyrus-5.1.0.13439.tar.gz: Zephyrus-5.1.0.13439/Zephyrus/blog_extension/migrations/0004_auto_20180520_0328.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('cms', '0020_old_tree_cleanup'),
        ('aldryn_categories', '0004_auto_20150623_0859'),
        ('blog_extension', '0003_auto_20180506_1620'),
    ]

    operations = [
        migrations.CreateModel(
            name='FilterPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_filterplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('limit', models.PositiveIntegerField(default=6)),
                ('filterMethod', models.CharField(default=b'or', max_length=3, verbose_name='Filter Method', choices=[(b'or', 'OR'), (b'and', 'AND')])),
                ('renderTemplate', models.CharField(default=b'blog_extension/Default.html', max_length=150, verbose_name='Comment Template', choices=[(b'blog_extension/Default.html', 'Default'), (b'aldryn_newsblog/blog/MayLike.html', b'Blog')])),
                ('catagory', models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True, on_delete=models.CASCADE)),
                ('tag', models.ManyToManyField(default=None, to='taggit.Tag', null=True, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='catagory',
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='cmsplugin_ptr',
        ),
        migrations.RemoveField(
            model_name='maylikeplugin',
            name='tag',
        ),
        migrations.DeleteModel(
            name='MayLikePlugin',
        ),
    ]
